@@ -9,13 +9,15 @@
 #
 package Config::Model::CheckList ;
 {
-  $Config::Model::CheckList::VERSION = '2.011';
+  $Config::Model::CheckList::VERSION = '2.029';
 }
 use Any::Moose ;
+use 5.010 ;
 
 use Config::Model::Exception ;
 use Config::Model::IdElementReference ;
 use Config::Model::Warper ;
+use List::MoreUtils qw/any none/;
 use Carp;
 use Log::Log4perl qw(get_logger :levels);
 use Storable qw/dclone/;
@@ -230,7 +232,13 @@ sub cargo_type {
     return 'leaf' ;
 }
 
+sub apply_fixes {
+    # no operation. THere's no check_value method because a check list 
+    # supposed to be always correct. Hence apply_fixes is empty.
+}
 
+
+# does not check the validity, but check the item of the check_list 
 sub check {
     my $self = shift ;
     my @list = ref $_[0] eq 'ARRAY' ? @{$_[0]} : @_ ;
@@ -241,7 +249,11 @@ sub check {
 	$self->{ref_object}->get_choice_from_refered_to ;
     }
 
-    map {$self->store($_ , 1, $check ) } @list ;
+    my @changed ;
+    map {push @changed,$_ if $self->store($_ , 1, $check ) } @list ;
+
+    $self->notify_change(note => "check @changed") 
+        unless $self->instance->initial_load;
 }
 
 # internal
@@ -259,22 +271,22 @@ sub store {
     }
 
     my $ok = $self->{choice_hash}{$choice} || 0 ;
+    my $changed = 0;
 
     if ($ok ) {
-	if ($inst->preset) {
-	    $self->{preset}{$choice} = $value ;
-	}
-	elsif ($inst->layered) {
-	    $self->{layered}{$choice} = $value ;
-	}
-	else {
-	    $self->{data}{$choice} = $value ;
-	}
+	my $data_name = $inst->preset  ? 'preset'
+                      : $inst->layered ? 'layered' 
+                      : 'data';
+        my $old_v = $self->{$data_name}{$choice} ;
+        if ( not defined $old_v or $old_v ne $value) {
+            $changed = 1;
+            $self->{$data_name}{$choice} = $value ;
+        }
+	
 	if ($self->{ordered} and $value) {
 	    my $ord = $self->{ordered_data} ;
 	    push @$ord,$choice unless scalar grep {$choice eq $_} @$ord ;
 	}
-	$self->notify_change unless $self->instance->initial_load;
     }
     elsif ($check eq 'yes')  {
 	my $err_str = "Unknown check_list item '$choice'. Expected '"
@@ -284,6 +296,8 @@ sub store {
         Config::Model::Exception::WrongValue 
 	    -> throw ( error =>  $err_str , object => $self) ;
     }
+    
+    return $changed ;
 }
 
 
@@ -297,7 +311,11 @@ sub uncheck {
 	$self->{ref_object}->get_choice_from_refered_to ;
     }
 
-    map {$self->store($_ , 0 , $check) } @list ;
+    my @changed  ;
+    map { push @changed, $_ if $self->store($_ , 0, $check ) } @list ;
+
+    $self->notify_change(note => "uncheck @changed") 
+        unless $self->instance->initial_load;
 }
 
 
@@ -443,7 +461,17 @@ sub get_checked_list_as_hash {
     my $ud  = $self->{upstream_default_data} ;
 
     # copy hash and return it
-    my %std = (%h, %$ud, %$lay, %$def, %$pre ) ;
+    my %predef  = (%h, %$def, %$pre )  ;
+    my %std     = (%h, %$ud, %$lay, %$def, %$pre ) ;
+
+    # use _std_backup if all data values are null (no checked items by user)
+    my %old_dat = (none { $_ ;} values %$dat) ?  %{$self->{_std_backup} || {}} : %$dat ;
+
+    if (not $mode and any {$_;} values %predef and none { $_ ;} values %old_dat) {
+        # changed from nothing to default checked list that must be written
+        $self->{_std_backup} = \%predef ;
+        $self->notify_change(note => "use default checklist") ;
+    }
 
     # custom test must compare the whole list at once, not just one item at a time.
     my %result 
@@ -453,7 +481,7 @@ sub get_checked_list_as_hash {
       : $mode eq 'upstream_default' ? (%h, %$ud) 
       : $mode eq 'default'          ? (%h, %$def )
       : $mode eq 'standard' ? %std
-      :                       (%h, %$def, %$pre, %$dat );
+      :                       (%predef, %$dat );
 
     return wantarray ? %result : \%result;
 }
@@ -655,7 +683,7 @@ Config::Model::CheckList - Handle check list element
 
 =head1 VERSION
 
-version 2.011
+version 2.029
 
 =head1 SYNOPSIS
 
